@@ -4,7 +4,7 @@ Main interface for iotanalytics service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_iotanalytics import (
         Client,
         IoTAnalyticsClient,
@@ -15,10 +15,8 @@ Usage::
         ListPipelinesPaginator,
     )
 
-    session = boto3.Session()
-
-    client: IoTAnalyticsClient = boto3.client("iotanalytics")
-    session_client: IoTAnalyticsClient = session.client("iotanalytics")
+    session = Session()
+    client: IoTAnalyticsClient = session.client("iotanalytics")
 
     list_channels_paginator: ListChannelsPaginator = client.get_paginator("list_channels")
     list_dataset_contents_paginator: ListDatasetContentsPaginator = client.get_paginator("list_dataset_contents")
